@@ -1,4 +1,7 @@
-magimage<-function(x, y, z, zlim, xlim, ylim, col = grey((0:1e3)/1e3), add = FALSE, useRaster=TRUE, asp=1, magmap=TRUE, locut=0.4, hicut=0.995, flip=FALSE, range=c(0,1), type = "quan", stretch="asinh", stretchscale='auto', bad=NA, clip="", axes=TRUE, frame.plot=TRUE, sparse='auto', qdiff=FALSE, ...){ 
+magimage<-function(x, y, z, zlim, xlim, ylim, col = grey((0:1e3)/1e3), add = FALSE,
+                   useRaster=TRUE, asp=1, magmap=TRUE, locut=0.4, hicut=0.995, flip=FALSE,
+                   range=c(0,1), type = "quan", stretch="asinh", stretchscale='auto',
+                   bad=NA, clip="", axes=TRUE, frame.plot=TRUE, sparse='auto', qdiff=FALSE, rem_med=FALSE, ...){ 
   dots=list(...)
   dotskeepimage=c('xaxs', 'yaxs', 'breaks', 'oldstyle')
   if(length(dots)>0){
@@ -36,6 +39,10 @@ magimage<-function(x, y, z, zlim, xlim, ylim, col = grey((0:1e3)/1e3), add = FAL
     if(missing(x)){x=seq(0.5,dim(z)[1]-0.5)}
   }
   
+  if(rem_med){
+    z = z - median(z, na.rm=TRUE)
+  }
+  
   if(missing(xlim) & length(x)==dim(z)[1]){
     xlim=range(x, na.rm=TRUE)+c(-0.5,0.5)*diff(range(x, na.rm=TRUE))/(dim(z)[1]-1)
   }
