@@ -8,11 +8,11 @@ magimageRGB<-function(x, y, R, G, B, saturation=1, zlim, xlim, ylim, add = FALSE
   }
   if(!missing(x)){
     if(is.list(x)){
-      if('y' %in% names(x)){y=x$y}
-      if('z' %in% names(x)){z=x$z}
       if('R' %in% names(x)){R=x$R}
-      if('G' %in% names(x)){R=x$G}
-      if('B' %in% names(x)){R=x$B}
+      if('G' %in% names(x)){G=x$G}
+      if('B' %in% names(x)){B=x$B}
+      if('y' %in% names(x)){y=x$y}else{y=seq(0.5,dim(R)[2]-0.5)}
+      if('x' %in% names(x)){x=x$x}else{x=seq(0.5,dim(R)[1]-0.5)}
     }
     if(is.array(x)){
       R=x[,,1]
@@ -40,8 +40,12 @@ magimageRGB<-function(x, y, R, G, B, saturation=1, zlim, xlim, ylim, add = FALSE
   if(missing(ylim) & length(y)==(dim(R)[2]+1)){
     ylim=range(y, na.rm=TRUE)
   }
-  if(x[1]>x[length(x)]){x=rev(x); xlim=rev(xlim)}
-  if(y[1]>y[length(y)]){y=rev(y); ylim=rev(ylim)}
+  if(is.numeric(x)){
+    if(x[1]>x[length(x)]){x=rev(x); xlim=rev(xlim)}
+  }
+  if(is.numeric(y)){
+    if(y[1]>y[length(y)]){y=rev(y); ylim=rev(ylim)}
+  }
   if(sparse=='auto'){
     sparse=ceiling(max(dim(R)/1e3))
   }
@@ -57,12 +61,13 @@ magimageRGB<-function(x, y, R, G, B, saturation=1, zlim, xlim, ylim, add = FALSE
   if(missing(zlim)){
     zlim=c(0,length(R))
   }
-  if(length(locut)<3){locut=rep(locut,3)}
-  if(length(hicut)<3){hicut=rep(hicut,3)}
+  if(length(locut)<3){locut=rep(locut[1],3)}
+  if(length(hicut)<3){hicut=rep(hicut[1],3)}
+  if(length(stretchscale)<3){stretchscale=rep(stretchscale[1],3)}
   if(magmap){
-    R=magmap(data=R, locut=locut[1], hicut=hicut[1], flip=flip, range=range, type=type, stretch=stretch, stretchscale=stretchscale, bad=bad, clip=clip)$map
-    G=magmap(data=G, locut=locut[2], hicut=hicut[2], flip=flip, range=range, type=type, stretch=stretch, stretchscale=stretchscale, bad=bad, clip=clip)$map
-    B=magmap(data=B, locut=locut[3], hicut=hicut[3], flip=flip, range=range, type=type, stretch=stretch, stretchscale=stretchscale, bad=bad, clip=clip)$map
+    R=magmap(data=R, locut=locut[1], hicut=hicut[1], flip=flip, range=range, type=type, stretch=stretch, stretchscale=stretchscale[1], bad=bad, clip=clip)$map
+    G=magmap(data=G, locut=locut[2], hicut=hicut[2], flip=flip, range=range, type=type, stretch=stretch, stretchscale=stretchscale[2], bad=bad, clip=clip)$map
+    B=magmap(data=B, locut=locut[3], hicut=hicut[3], flip=flip, range=range, type=type, stretch=stretch, stretchscale=stretchscale[3], bad=bad, clip=clip)$map
   }
   
   if(saturation!=1){
